@@ -226,12 +226,13 @@ class StatsConfigManager(models.Manager):
 
 
 class ElementConfig(models.Model):
-    ENTITY_CONFIG, REL_CONFIG, PROPERTY_CONFIG, STATS_CONFIG = 1, 2, 3, 4
+    ENTITY_CONFIG, REL_CONFIG, PROPERTY_CONFIG, STATS_CONFIG, CUSTOM_CONFIG = 1, 2, 3, 4, 5
     TYPE_CHOICES = [
         (ENTITY_CONFIG, "entity"),
         (REL_CONFIG, "relationship"),
         (PROPERTY_CONFIG, "property"),
         (STATS_CONFIG, "stats"),
+        (CUSTOM_CONFIG, "custom"),
     ]
     PARENT_TYPE_CHOICES = [
         (ENTITY_CONFIG, "entity"),
